[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
03/06: gnu: cdrtools: Use G-expressions.
From: |
guix-commits |
Subject: |
03/06: gnu: cdrtools: Use G-expressions. |
Date: |
Wed, 16 Mar 2022 15:42:24 -0400 (EDT) |
nckx pushed a commit to branch master
in repository guix.
commit 0ac0f43a90dc08eac014447d7702abe0029e073d
Author: Tobias Geerinckx-Rice <me@tobias.gr>
AuthorDate: Sun Mar 13 01:00:01 2022 +0100
gnu: cdrtools: Use G-expressions.
* gnu/packages/cdrom.scm (cdrtools)[arguments]:
Rewrite as G-expressions. Don't return #t from phases.
---
gnu/packages/cdrom.scm | 53 +++++++++++++++++++++++++-------------------------
1 file changed, 26 insertions(+), 27 deletions(-)
diff --git a/gnu/packages/cdrom.scm b/gnu/packages/cdrom.scm
index 20e7a55e2d..4401420fe7 100644
--- a/gnu/packages/cdrom.scm
+++ b/gnu/packages/cdrom.scm
@@ -319,33 +319,32 @@ format, commonly used for VCDs or disks with subchannel
data.")
(build-system gnu-build-system)
;; XXX cdrtools bundles a modified, relicensed early version of cdparanoia.
(arguments
- `(#:make-flags
- (list "RM=rm" "LN=ln" "SYMLINK=ln -s"
- "CONFIG_SHELL=sh"
- (string-append "CCOM=" ,(cc-for-target))
- "LINKMODE=dynamic"
- (string-append "INS_BASE=" (assoc-ref %outputs "out"))
- (string-append "INS_RBASE=" (assoc-ref %outputs "out")))
- ;; Parallel builds appear to be unsafe, see
- ;; https://hydra.gnu.org/build/3346840/log/raw
- #:parallel-build? #f
- #:phases
- (modify-phases %standard-phases
- (delete 'configure)
- (add-before 'build 'set-linux-headers
- (lambda _
- (substitute* "autoconf/configure"
- (("/usr/src/linux")
- (assoc-ref %build-inputs "kernel-headers")))
- #t))
- (add-before 'build 'substitute-dirs
- (lambda _
- (substitute* (append (find-files "DEFAULTS" "^Defaults\\.")
- (find-files "DEFAULTS_ENG" "^Defaults\\.")
- (find-files "TEMPLATES" "^Defaults\\."))
- (("/opt/schily") (assoc-ref %outputs "out")))
- #t)))
- #:tests? #f)) ; no tests
+ (list #:make-flags
+ #~(list "RM=rm" "LN=ln" "SYMLINK=ln -s"
+ "CONFIG_SHELL=sh"
+ (string-append "CCOM=" #$(cc-for-target))
+ "LINKMODE=dynamic"
+ (string-append "INS_BASE=" #$output)
+ (string-append "INS_RBASE=" #$output))
+ ;; Parallel builds appear to be unsafe, see
+ ;; https://hydra.gnu.org/build/3346840/log/raw
+ #:parallel-build? #f
+ #:phases
+ #~(modify-phases %standard-phases
+ (delete 'configure)
+ (add-before 'build 'set-linux-headers
+ (lambda _
+ (substitute* "autoconf/configure"
+ (("/usr/src/linux")
+ (assoc-ref %build-inputs "kernel-headers")))))
+ (add-before 'build 'avoid-bogus-RPATH-entry
+ (lambda _
+ (substitute* (append (find-files "DEFAULTS" "^Defaults\\.")
+ (find-files "DEFAULTS_ENG" "^Defaults\\.")
+ (find-files "TEMPLATES" "^Defaults\\."))
+ (("/opt/schily")
+ #$output)))))
+ #:tests? #f)) ; no tests
(synopsis "Command line utilities to manipulate and burn CD/DVD/BD images")
(description "cdrtools is a collection of command line utilities to create
CD's, DVD's or Blue Ray discs. The most important components are
- branch master updated (21457fb31e -> 3076e69577), guix-commits, 2022/03/16
- 03/06: gnu: cdrtools: Use G-expressions.,
guix-commits <=
- 05/06: gnu: bind: Update to 9.16.27 [fixes CVE-2022-0396]., guix-commits, 2022/03/16
- 01/06: gnu: cdrtools: Prepare for cross-compilation., guix-commits, 2022/03/16
- 04/06: gnu: cdrtools: Don't return #t from snippet., guix-commits, 2022/03/16
- 02/06: gnu: cdrtools: Link dynamically., guix-commits, 2022/03/16
- 06/06: gnu: isc-dhcp: Update bundled BIND to 9.11.37., guix-commits, 2022/03/16